@@ -1,15 +1,14 @@
 package SPOPS::DBI::Pg;
 
-# $Id: Pg.pm,v 1.15 2002/01/08 04:31:53 lachoy Exp $
+# $Id: Pg.pm,v 1.18 2002/02/22 20:32:48 lachoy Exp $
 
 use strict;
 use SPOPS qw( _w DEBUG );
-use SPOPS::Key::DBI::Sequence;
 
-@SPOPS::DBI::Pg::ISA      = ();
-$SPOPS::DBI::Pg::VERSION  = '1.90';
-$SPOPS::DBI::Pg::Revision = substr(q$Revision: 1.15 $, 10);
+$SPOPS::DBI::Pg::VERSION  = substr(q$Revision: 1.18 $, 10);
 
+use constant PG_SEQUENCE_NEXT    => "NEXTVAL( '%s' )";
+use constant PG_SEQUENCE_CURRENT => "SELECT CURRVAL( '%s' )";
 
 sub sql_quote {
     my ( $class, $value, $type, $db ) = @_;
@@ -20,31 +19,29 @@ sub sql_quote {
     return $db->quote( $value, $type );
 }
 
-
-sub sql_current_date  { return 'CURRENT_TIMESTAMP()' }
-
+sub sql_current_date     { return 'CURRENT_TIMESTAMP()' }
+sub sql_case_insensitive { return '~*' }
 
 sub pre_fetch_id {
     my ( $item, $p ) = @_;
-    return undef if     ( $item->CONFIG->{increment_field} );
-    return undef unless ( $p->{sequence_name} = $item->CONFIG->{sequence_name} );
-    return SPOPS::Key::DBI::Sequence::retrieve_sequence( $item, $p );
+    my ( $seq_name );
+    return undef unless ( $item->CONFIG->{increment_field} );
+    return undef unless ( $seq_name = $item->CONFIG->{sequence_name} );
+    return sprintf( PG_SEQUENCE_NEXT, $seq_name );
 }
 
 
 sub post_fetch_id {
     my ( $item, $p ) = @_;
     return undef unless ( $item->CONFIG->{increment_field} );
-    if ( my $custom_sequence_name = $item->CONFIG->{sequence_name} ) {
-        $p->{sequence_name} = $custom_sequence_name;
-    }
-    unless ( $p->{sequence_name} ) {
-        $p->{sequence_name} = join( '_', $item->CONFIG->{base_table}, $item->CONFIG->{id_field}, 'seq' );
-    }
-    $p->{sequence_call} = q{ SELECT currval( '%s' ) };
-    DEBUG() && _w( 1, "Using sequence name of ($p->{sequence_name}) and ",
-                      "call of ($p->{sequence_call}) for Pg SERIAL field." );
-    return SPOPS::Key::DBI::Sequence::retrieve_sequence( $item, $p );
+    my $seq_name = $item->CONFIG->{sequence_name}
+                   || join( '_', $item->CONFIG->{base_table},
+                                 $item->CONFIG->{id_field},
+                                 'seq' );
+    return undef unless ( $seq_name );
+    my $sth = $p->{db}->prepare( sprintf( PG_SEQUENCE_CURRENT, $seq_name ) );
+    $sth->execute;
+    return ($sth->fetchrow_array)[0];
 }
 
 1;
@@ -64,18 +61,22 @@ SPOPS::DBI::Pg -- PostgreSQL-specific routines for the SPOPS::DBI
  'myspops' => {
      'isa' => [ qw/ SPOPS::DBI::Pg SPOPS::DBI / ],
 
-     # If you have a SERIAL/sequence field, set increment_field to
-     # true and name the sequence to be used
+     # If you have a SERIAL field, just set increment_field to a true
+     # value
 
      'increment_field' => 1,
+
+     # If you want to specify the name of your sequence (whether using
+     # a SERIAL field or not):
+
      'sequence_name'   => 'myseq',
      ...
  },
 
 =head1 DESCRIPTION
 
-This just implements some Postgres-specific routines so we
-can abstract them out.
+This just implements some Postgres-specific routines so we can
+abstract them out.
 
 One of them optionally returns the sequence value of the just-inserted
 id field. Of course, this only works if you have a the field marked as
@@ -86,9 +87,19 @@ id field. Of course, this only works if you have a the field marked as
    ...
  )
 
-B<NOTE>: You also need to let this module know if you are using this
-option by setting in your class configuration the key
-'increment_field' to a true value:
+or
+
+ CREATE TABLE my_table (
+   id int not null primary key,
+   ...
+ );
+
+ CREATE SEQUENCE myobject_sequence;
+
+
+You must to let this module know if you are using this option by
+setting in your class configuration the key 'increment_field' to a
+true value:
 
  $spops = {
     myobj => {
@@ -99,17 +110,32 @@ option by setting in your class configuration the key
     },
  };
 
-You can also specify the sequence name in the object configuration:
+If you use the 'SERIAL' datatype then you do not have to specify a
+sequence name. Otherwise you need to tell SPOPS what sequence to use
+in the class configuration:
 
  $spops = {
     myobj => {
-       class => 'My::Object',
-       isa   => [ qw/ SPOPS::DBI::Pg  SPOPS::DBI / ],
+       class           => 'My::Object',
+       isa             => [ qw/ SPOPS::DBI::Pg  SPOPS::DBI / ],
        increment_field => 1,
-       sequence_name => 'myobject_sequence',
+       sequence_name   => 'myobject_sequence',
     },
  };
 
+B<NOTE>: The name automatically created by PostgreSQL when you use the
+'SERIAL' datatype follows a certain convention
+($table-$idfield-seq). But if the table or ID field are too long,
+PostgreSQL will truncate the name so it will fit in the 32-character
+limit for symbols. In this case you will either need to recompile
+PostgreSQL (yuck) or list the sequence name in the class
+configuration. See a message from the openinteract-help mailing list
+at:
+
+  http://www.geocrawler.com/archives/3/8429/2002/1/0/7551783/
+
+for more information on recompiling if you are so inclined.
+
 =head1 METHODS
 
 B<sql_current_date()>
@@ -131,16 +157,9 @@ with the class method C<global_db_handle()>.
 
 B<pre_fetch_id( \%params )>
 
-We only fetch an ID if 'increment_field' is B<NOT> set and
-'sequence_name' B<IS> set in the configuration for the SPOPS object.
-This enables you to retrieve an ID value from a sequence before the
-insert. Although this should not make any difference to the SPOPS
-user, it might make a difference to an application so the option is
-here.
-
-Auto-incrementing fields (represented by a trigger or the 'SERIAL'
-datatype) are retrieved after the INSERT has been done (see
-C<post_fetch_id()> below).
+If 'increment_field' is not set we do not fetch an ID. If
+'sequence_name' is not also set we do not fetch an ID, assuming that
+you have defined the ID field using the 'SERIAL' datatype.
 
 B<post_fetch_id( \%params )>
 
@@ -164,8 +183,6 @@ Nothing known.
 
 =head1 SEE ALSO
 
-L<SPOPS::Key::DBI::Sequence|SPOPS::Key::DBI::Sequence>
-
 L<DBD::Pg|DBD::Pg>
 
 L<DBI|DBI>
