@@ -1,6 +1,6 @@
 package My::LDAPConnect;
 
-# $Id: LDAPConnect.pm,v 1.2 2001/10/26 03:21:35 lachoy Exp $
+# $Id: LDAPConnect.pm,v 1.3 2002/01/08 04:31:53 lachoy Exp $
 
 # Simple LDAP connection manager -- change %DATASOURCE as needed for testing
 
@@ -32,14 +32,18 @@ sub global_datasource_handle {
         $ldap_info->{port} ||= 389;
         my $ldap = Net::LDAP->new( $ldap_info->{host},
                                    port => $ldap_info->{port} );
-        die "Cannot create LDAP connection!\n" unless ( $ldap );
+        unless ( $ldap ) { SPOPS::Exception->throw( "Cannot create LDAP connection: [$@]" ) }
         my ( %bind_params );
         if ( $ldap_info->{bind_dn} ) {
             $bind_params{dn}       = $ldap_info->{bind_dn};
             $bind_params{password} = $ldap_info->{bind_password};
         }
         my $bind_msg = $ldap->bind( %bind_params );
-        die "Cannot bind! Error: ", $bind_msg->error, "\n" if ( $bind_msg->code );
+        if ( my $code = $bind_msg->code ) {
+            SPOPS::Exception::LDAP->throw(
+                              "Cannot bind to directory: " . $bind_msg->error,
+                              { code => $code, action => 'global_datasource_handle' } );
+        }
         $HANDLES{ $connect_key } = $ldap;
     }
     return $HANDLES{ $connect_key };
